-
Notifications
You must be signed in to change notification settings - Fork 515
PDFKit macOS xcode14.3 beta3
Alex Soto edited this page Mar 22, 2023
·
2 revisions
#PDFKit.framework https://github.com/xamarin/xamarin-macios/pull/17810
diff -ruN /Applications/Xcode_14.3.0-beta2.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/PDFKit.framework/Headers/PDFKit.apinotes /Applications/Xcode_14.3.0-beta3.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/PDFKit.framework/Headers/PDFKit.apinotes
--- /Applications/Xcode_14.3.0-beta2.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/PDFKit.framework/Headers/PDFKit.apinotes 2023-02-17 23:00:16
+++ /Applications/Xcode_14.3.0-beta3.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/PDFKit.framework/Headers/PDFKit.apinotes 2023-02-25 23:53:46
@@ -25,3 +25,8 @@
SwiftName: PDFDocumentWriteOption.burnInAnnotations
- Name: PDFDocumentSaveTextFromOCROption
SwiftName: PDFDocumentWriteOption.saveTextFromOCR
+ - Name: PDFDocumentSaveImagesAsJPEGOption
+ SwiftName: PDFDocumentWriteOption.saveImagesAsJPEG
+ - Name: PDFDocumentOptimizeImagesForScreenOption
+ SwiftName: PDFDocumentWriteOption.optimizeImagesForScreen
+
- README
- xcode13.0 Binding Status
- xcode13.1 Binding Status
- xcode13.2 Binding Status
- xcode13.3 Binding Status
- xcode13.4 Binding Status
- xcode14.0 Binding Status
- xcode14.1 Binding Status
- xcode14.2 Binding Status
- xcode14.3 Binding Status
- xcode15.0 Binding Status
- xcode15.1 Binding Status
- xcode15.3 Binding Status
- xcode15.4 Binding Status
- xcode16.0 Binding Status
- xcode16.1 Binding Status
- xcode16.2 Binding Status
diff -ruN /Applications/Xcode_14.3.0-beta2.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/PDFKit.framework/Headers/PDFDocument.h /Applications/Xcode_14.3.0-beta3.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/PDFKit.framework/Headers/PDFDocument.h
--- /Applications/Xcode_14.3.0-beta2.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/PDFKit.framework/Headers/PDFDocument.h 2023-02-24 11:28:34
+++ /Applications/Xcode_14.3.0-beta3.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/PDFKit.framework/Headers/PDFDocument.h 2023-03-09 18:43:23
@@ -95,10 +95,14 @@
// Users can have limited access to modify, print, or write the file.
PDFKIT_EXTERN PDFDocumentWriteOption const PDFDocumentAccessPermissionsOption PDFKIT_AVAILABLE(12_0, 15_0); // NSNumber containing a PDFAccessPermissions
-PDFKIT_EXTERN PDFDocumentWriteOption const PDFDocumentBurnInAnnotationsOption PDFKIT_AVAILABLE(13_0, 16_0); // @YES to enable, disabled by default
+PDFKIT_EXTERN PDFDocumentWriteOption const PDFDocumentBurnInAnnotationsOption PDFKIT_AVAILABLE(13_0, 16_0); // @YES to enable, disabled by default
// If enabled, annotations will be rendered into the content stream and NOT saved as annotations
-PDFKIT_EXTERN PDFDocumentWriteOption const PDFDocumentSaveTextFromOCROption PDFKIT_AVAILABLE(13_0, 16_0); // @YES to enable, disabled by default
- // If enabled, OCR will be performed on all pages on which it has not been done already and saved as invisible, but selectable. text
+PDFKIT_EXTERN PDFDocumentWriteOption const PDFDocumentSaveTextFromOCROption PDFKIT_AVAILABLE(13_0, 16_0); // @YES to enable, disabled by default
+ // If enabled, OCR will be performed on all pages on which it has not been done already and saved as invisible, but selectable, text
+PDFKIT_EXTERN PDFDocumentWriteOption const PDFDocumentSaveImagesAsJPEGOption PDFKIT_AVAILABLE(13_4, 16_4); // @YES to enable, disabled by default
+ // If enabled, images will be saved using JPEG encoding.
+PDFKIT_EXTERN PDFDocumentWriteOption const PDFDocumentOptimizeImagesForScreenOption PDFKIT_AVAILABLE(13_4, 16_4); // @YES to enable, disabled by default
+ // If enabled, the resolution of images will be limited to a resolution appropriate for screen display.
// Some PDF access permissions are non-strict supersets of other permissions. Granting access to a superset